API Reference
=============

This page contains auto-generated API reference documentation [#f1]_.

.. toctree::
   :titlesonly:

   autodoc2/autodoc2
   aiida/aiida

.. [#f1] Created with `sphinx-autodoc2`
